﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using TXTextControl.DocumentServer.Fields;
using TXTextControl;

namespace tx_template_designer_sample
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            // connect the controls
            textControl1.RulerBar = rulerBar2;
            textControl1.ButtonBar = buttonBar1;
            textControl1.StatusBar = statusBar1;
            textControl1.VerticalRulerBar = rulerBar1;
        }

        // global DataSet
        DataSet ds = new DataSet();

        private void btnOpenDatabase_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() != DialogResult.OK)
                return;

            // reset the document, if a new table is selected
            textControl1.ResetContents();
            cboTables.Items.Clear();

            // open the database
            ds.ReadXml(openFileDialog1.FileName, XmlReadMode.Auto);

            lblDatabaseName.Text = openFileDialog1.SafeFileName;

            foreach (DataTable table in ds.Tables)
            {
                cboTables.Items.Add(table);
            }

            btnOpenDatabase.BackColor = Color.FromKnownColor(KnownColor.Control);
            cboTables.BackColor = Color.LightGreen;
        }

        private void cboTables_SelectedIndexChanged(object sender, EventArgs e)
        {
            cboFields.Items.Clear();

            // add the existing fields to the combobox
            foreach (DataColumn col in ds.Tables[cboTables.Text].Columns)
            {
                cboFields.Items.Add(col);
            }

            cboFields.SelectedIndex = 0;

            // set the bindings for the navigator toolbar
            bindingNavigator1.BindingSource = new BindingSource(ds, ds.Tables[cboTables.Text].ToString());

            cboTables.BackColor = Color.FromKnownColor(KnownColor.Control);
            cboFields.BackColor = Color.LightGreen;
        }

        private void cboFields_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cboFields.SelectedIndex >= 0)
            {
                btnAddField.Enabled = true;

                cboFields.BackColor = Color.FromKnownColor(KnownColor.Control);
                btnAddField.BackColor = Color.LightGreen;
            }
            else
                btnAddField.Enabled = false;
        }

        private void btnAddField_Click(object sender, EventArgs e)
        {
            // create a new adapter MergeField
            MergeField newField = new MergeField();
            newField.Name = cboFields.Text;
            newField.Text = "{" + cboFields.Text + "}";
            newField.ApplicationField.DoubledInputPosition = true;
            newField.ApplicationField.ShowActivated = true;

            // add the field to the document
            textControl1.ApplicationFields.Add(newField.ApplicationField);

            updatePreview();
        }

        private void updatePreview()
        {
            // this method updates the text of all fields
            try
            {
                foreach (ApplicationField appField in textControl1.ApplicationFields)
                {
                    if (appField.TypeName != "MERGEFIELD")
                        return;
                    
                    MergeField mergeField = new MergeField(appField);

                    if (bindingNavigator1.Enabled && btnPreview.Checked)
                        mergeField.Text = ((DataRowView)bindingNavigator1.BindingSource.Current)[mergeField.Name].ToString();
                    else
                        mergeField.Text = "{" + mergeField.Name + "}";
                }
            }
            catch { }
        }

        private void btnPreview_Click(object sender, EventArgs e)
        {
            bindingNavigator1.Enabled = btnPreview.Checked;
            updatePreview();
        }

        private void bindingNavigatorPositionItem_TextChanged(object sender, EventArgs e)
        {
            updatePreview();
        }

        private void saveAsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveSettings set = new SaveSettings();

            textControl1.Save(StreamType.MSWord | StreamType.RichTextFormat | StreamType.WordprocessingML, set);
        }

    }
}

